Struct AvailableRangeResponse
pub struct AvailableRangeResponse {
pub min_checkpoint: Option<u64>,
pub max_checkpoint: Option<u64>,
pub max_epoch: Option<u64>,
pub total_transactions: Option<u64>,
pub max_timestamp_ms: Option<u64>,
pub stride: Option<u64>,
}Fields
min_checkpoint: Option<u64>The (inclusive) minimum checkpoint sequence number that the service can answer questions for.
max_checkpoint: Option<u64>The (inclusive) maximum checkpoint sequence number that the service can answer questions for.
max_epoch: Option<u64>The (inclusive) maximum epoch that the service can answer questions for.
total_transactions: Option<u64>The total number of transactions that have executed on chain by the end of
the max_checkpoint.
max_timestamp_ms: Option<u64>The (inclusive) maximum timestamp that the service can answer questions for, in milliseconds since the Unix epoch.
stride: Option<u64>The gaps between snapshots taken by the service, measured in checkpoints.
Accessible checkpoints in the available range are evenly spaced out
stride checkpoints apart.
Implementations
impl AvailableRangeResponse
impl AvailableRangeResponse
pub fn min_checkpoint(&self) -> u64
pub fn min_checkpoint(&self) -> u64
Returns the value of min_checkpoint, or the default value if min_checkpoint is unset.
pub fn max_checkpoint(&self) -> u64
pub fn max_checkpoint(&self) -> u64
Returns the value of max_checkpoint, or the default value if max_checkpoint is unset.
pub fn max_epoch(&self) -> u64
pub fn max_epoch(&self) -> u64
Returns the value of max_epoch, or the default value if max_epoch is unset.
pub fn total_transactions(&self) -> u64
pub fn total_transactions(&self) -> u64
Returns the value of total_transactions, or the default value if total_transactions is unset.
pub fn max_timestamp_ms(&self) -> u64
pub fn max_timestamp_ms(&self) -> u64
Returns the value of max_timestamp_ms, or the default value if max_timestamp_ms is unset.