Struct Balance
pub struct Balance {
pub owner: Option<String>,
pub coin_type: Option<String>,
pub total_balance: Option<u64>,
pub address_balance: Option<u64>,
pub coin_balance: Option<u64>,
pub page_token: Option<Bytes>,
}Fields
owner: Option<String>Address of the owner whose balance is being reported.
coin_type: Option<String>The marker type for the coins being aggregated into this balance, e.g.
0x0000000000000000000000000000000000000000000000000000000000000002::sui::SUI.
total_balance: Option<u64>The sum total of the accumulator balance and coins of this type, owned by one address, denominated in its smallest unit.
address_balance: Option<u64>Total balance of the coin type as tracked by the accumulator object for the address.
coin_balance: Option<u64>Total balance for coins of this type owned by the address.
page_token: Option<Bytes>Pagination cursor pointing to this balance entry, if this Balance is part of a paginated response.
Implementations
impl Balance
impl Balance
pub fn coin_type(&self) -> &str
pub fn coin_type(&self) -> &str
Returns the value of coin_type, or the default value if coin_type is unset.
pub fn total_balance(&self) -> u64
pub fn total_balance(&self) -> u64
Returns the value of total_balance, or the default value if total_balance is unset.
pub fn address_balance(&self) -> u64
pub fn address_balance(&self) -> u64
Returns the value of address_balance, or the default value if address_balance is unset.
pub fn coin_balance(&self) -> u64
pub fn coin_balance(&self) -> u64
Returns the value of coin_balance, or the default value if coin_balance is unset.
pub fn page_token(&self) -> &[u8] ⓘ
pub fn page_token(&self) -> &[u8] ⓘ
Returns the value of page_token, or the default value if page_token is unset.