Struct ListBalancesRequest
pub struct ListBalancesRequest {
pub owner: Option<String>,
pub page_size: Option<u32>,
pub after_token: Option<Bytes>,
pub before_token: Option<Bytes>,
pub end: Option<i32>,
}Fields
owner: Option<String>Required. The address of the owner whose balances are being requested.
page_size: Option<u32>The maximum number of entries to return. The service may return fewer than this value.
Consult sui.rpc.consistent.v1alpha/ServiceConfig for default and maximum
page sizes.
after_token: Option<Bytes>A page token, received from a previous ListOwnedObjects call.
Provide this to retrieve the next page.
before_token: Option<Bytes>A page token, received from a previous ListOwnedObjects call.
Provide this to retrieve the previous page.
end: Option<i32>Whether to fetch the next page from the front or back of the filtered range.
Implementations
impl ListBalancesRequest
impl ListBalancesRequest
pub fn page_size(&self) -> u32
pub fn page_size(&self) -> u32
Returns the value of page_size, or the default value if page_size is unset.
pub fn after_token(&self) -> &[u8] ⓘ
pub fn after_token(&self) -> &[u8] ⓘ
Returns the value of after_token, or the default value if after_token is unset.
pub fn before_token(&self) -> &[u8] ⓘ
pub fn before_token(&self) -> &[u8] ⓘ
Returns the value of before_token, or the default value if before_token is unset.