Struct ListOwnedObjectsRequest
pub struct ListOwnedObjectsRequest {
pub owner: Option<Owner>,
pub object_type: Option<String>,
pub page_size: Option<u32>,
pub after_token: Option<Bytes>,
pub before_token: Option<Bytes>,
pub end: Option<i32>,
}Fields
owner: Option<Owner>Required. The owner kind and address.
object_type: Option<String>Optional type filter to limit or exclude the types of objects listed.
Accepts filters by the type’s package, module, fully-qualified name, or a type instantiation:
0x20x2::coin0x2::coin::Coin0x2::coin::Coin<0x2::sui::SUI>
When preceded by an !, objects of the type prefix will be excluded from the returned
response.
page_size: Option<u32>The maximum number of entries to return. The service may return fewer than this value.
Consult sui.rpc.consistent.v1alpha/ServiceConfig for default and maximum
page sizes.
after_token: Option<Bytes>A page token, received from a previous ListOwnedObjects call.
Provide this to retrieve the next page.
before_token: Option<Bytes>A page token, received from a previous ListOwnedObjects call.
Provide this to retrieve the previous page.
end: Option<i32>Whether to fetch the next page from the front or back of the filtered range.
Implementations
impl ListOwnedObjectsRequest
impl ListOwnedObjectsRequest
pub fn object_type(&self) -> &str
pub fn object_type(&self) -> &str
Returns the value of object_type, or the default value if object_type is unset.
pub fn page_size(&self) -> u32
pub fn page_size(&self) -> u32
Returns the value of page_size, or the default value if page_size is unset.
pub fn after_token(&self) -> &[u8] ⓘ
pub fn after_token(&self) -> &[u8] ⓘ
Returns the value of after_token, or the default value if after_token is unset.
pub fn before_token(&self) -> &[u8] ⓘ
pub fn before_token(&self) -> &[u8] ⓘ
Returns the value of before_token, or the default value if before_token is unset.